<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk">
<context>
    <name>ActionManager</name>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>&amp;Play</source>
        <translation>&amp;Hrať</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pozastaviť</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>&amp;Stop</source>
        <translation>Za&amp;staviť</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>&amp;Previous</source>
        <translation>&amp;Predchádzajúca</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>&amp;Next</source>
        <translation>&amp;Nasledujúca</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>&amp;Play/Pause</source>
        <translation>&amp;Hrať/Pozastaviť</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>Space</source>
        <translation>Medzerník</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>J</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>&amp;Jump to Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>&amp;Repeat Playlist</source>
        <translation>&amp;Opakovať playlist</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>&amp;Repeat Track</source>
        <translation>&amp;Opakovať skladbu</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="47"/>
        <source>&amp;Shuffle</source>
        <translation>&amp;Zamiešať</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="47"/>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="48"/>
        <source>&amp;No Playlist Advance</source>
        <translation>&amp;Nepokročilý playlist</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="49"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="50"/>
        <source>&amp;Stop After Selected</source>
        <translation>&amp;Zastaviť po vybranej</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="51"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="52"/>
        <source>&amp;Clear Queue</source>
        <translation>&amp;Vyčistiť rad</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="52"/>
        <source>Alt+Q</source>
        <translation>Alt+Q</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Show Playlist</source>
        <translation>Ukázať playlist</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="55"/>
        <source>Show Equalizer</source>
        <translation>Ukázať ekvalizér</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="55"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="56"/>
        <source>Always on Top</source>
        <translation>Vždy na vrchu</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="57"/>
        <source>Put on All Workspaces</source>
        <translation>Dať na všetky plochy</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="58"/>
        <source>Double Size</source>
        <translation>Dvojitá veľkosť</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="58"/>
        <source>Meta+D</source>
        <translation>Meta+D</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>&amp;Add File</source>
        <translation>&amp;Pridať súbor</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>&amp;Add Directory</source>
        <translation>&amp;Pridať priečinok</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="62"/>
        <source>&amp;Add Url</source>
        <translation>&amp;Pridať URL</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="62"/>
        <source>U</source>
        <translation>U</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="63"/>
        <source>&amp;Remove Selected</source>
        <translation>Odst&amp;rániť vybraté</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="64"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="65"/>
        <source>&amp;Remove All</source>
        <translation>Odst&amp;rániť všetko</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="66"/>
        <source>&amp;Remove Unselected</source>
        <translation>Odst&amp;rániť nevybraté</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="68"/>
        <source>Remove unavailable files</source>
        <translation>Odstrániť nedostupné súbory</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="70"/>
        <source>Remove duplicates</source>
        <translation>Odstrániť duplikáty</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="71"/>
        <source>&amp;Queue Toggle</source>
        <translation>&amp;Zaradiť prepínanie</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="71"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="72"/>
        <source>Invert Selection</source>
        <translation>Invertovať výber</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="73"/>
        <source>&amp;Select None</source>
        <translation>Zrušiť &amp;výber</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="74"/>
        <source>&amp;Select All</source>
        <translation>&amp;Vybrať všetko</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="75"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="76"/>
        <source>&amp;View Track Details</source>
        <translation>&amp;Zobraziť detaily o skladbe</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="76"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>&amp;New List</source>
        <translation>&amp;Nový zoznam</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>&amp;Delete List</source>
        <translation>&amp;Vymazať zoznam</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>&amp;Load List</source>
        <translation>&amp;Načítať zoznam</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="81"/>
        <source>&amp;Save List</source>
        <translation>&amp;Uložiť zoznam</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="81"/>
        <source>Shift+S</source>
        <translation>Shift+S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="82"/>
        <source>&amp;Select Next Playlist</source>
        <translation>&amp;Vybrať nasledujúci playlist</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="83"/>
        <source>Ctrl+PgDown</source>
        <translation>Ctrl+Page Down</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="84"/>
        <source>&amp;Select Previous Playlist</source>
        <translation>&amp;Vybrať predchádzajúci playlist</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="85"/>
        <source>Ctrl+PgUp</source>
        <translation>Ctrl+Page Up</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="86"/>
        <source>&amp;Show Playlists</source>
        <translation>&amp;kázať playlisty</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="87"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>&amp;Settings</source>
        <translation>Na&amp;stavenia</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="90"/>
        <source>&amp;About</source>
        <translation>O progr&amp;ame</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>&amp;About Qt</source>
        <translation>&amp;O Qt</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="92"/>
        <source>&amp;Exit</source>
        <translation>&amp;Ukončiť</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="92"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
</context>
<context>
    <name>EqWidget</name>
    <message>
        <location filename="../eqwidget.cpp" line="44"/>
        <source>Equalizer</source>
        <translation>Ekvalizér</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="157"/>
        <location filename="../eqwidget.cpp" line="178"/>
        <source>preset</source>
        <translation>předvolba</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="264"/>
        <source>&amp;Load/Delete</source>
        <translation>&amp;Načíst/Odstranit</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="266"/>
        <source>&amp;Save Preset</source>
        <translation>&amp;Uložit předvolbu</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="268"/>
        <source>&amp;Save Auto-load Preset</source>
        <translation>Uložit &amp;automatickou předvolbu</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="270"/>
        <source>&amp;Import</source>
        <translation>&amp;Importovat</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="273"/>
        <source>&amp;Clear</source>
        <translation>&amp;Vynulovat</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="302"/>
        <source>Saving Preset</source>
        <translation>Uložení předvolby</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="303"/>
        <source>Preset name:</source>
        <translation>Název předvolby:</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="304"/>
        <source>preset #</source>
        <translation>předvolba #</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="395"/>
        <source>Import Preset</source>
        <translation>Importovat předvolbu</translation>
    </message>
</context>
<context>
    <name>HotkeyEditor</name>
    <message>
        <location filename="../forms/hotkeyeditor.ui" line="27"/>
        <source>Action</source>
        <translation type="unfinished">Činnosť</translation>
    </message>
    <message>
        <location filename="../forms/hotkeyeditor.ui" line="32"/>
        <source>Shortcut</source>
        <translation type="unfinished">Skratka</translation>
    </message>
    <message>
        <location filename="../forms/hotkeyeditor.ui" line="40"/>
        <source>Change shortcut...</source>
        <translation type="unfinished">Zmeniť skratku...</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="55"/>
        <source>Playback</source>
        <translation type="unfinished">Prehrávanie</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="61"/>
        <source>View</source>
        <translation type="unfinished">Zobraziť</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="67"/>
        <source>Playlist</source>
        <translation type="unfinished">Playlist</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="73"/>
        <source>Misc</source>
        <translation type="unfinished">Rôzn.</translation>
    </message>
</context>
<context>
    <name>MainDisplay</name>
    <message>
        <location filename="../display.cpp" line="57"/>
        <source>Previous</source>
        <translation>Predchádzajúca</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="61"/>
        <source>Play</source>
        <translation>Hrať</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="64"/>
        <source>Pause</source>
        <translation>Pozastaviť</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="67"/>
        <source>Stop</source>
        <translation>Zastaviť</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="70"/>
        <source>Next</source>
        <translation>Nasledujúca</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="73"/>
        <source>Add file</source>
        <translation>Pridať súbor</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="80"/>
        <source>Equalizer</source>
        <translation>Ekvalizér</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="83"/>
        <source>Playlist</source>
        <translation>Playlist</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="88"/>
        <source>Repeat playlist</source>
        <translation>Opakovať playlist</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="91"/>
        <source>Shuffle</source>
        <translation>Zamiešať</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="101"/>
        <source>Volume</source>
        <translation>Hlasitosť</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="107"/>
        <source>Balance</source>
        <translation>Vyváženie</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="296"/>
        <source>Volume: %1%</source>
        <translation>Hlasitosť: %1%</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="300"/>
        <source>Balance: %1% right</source>
        <translation>Vyváženie: %1% vpravo</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="302"/>
        <source>Balance: %1% left</source>
        <translation>Vyváženie: %1% vľavo</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="304"/>
        <source>Balance: center</source>
        <translation>Vyváženie: stred</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="315"/>
        <source>Seek to: %1</source>
        <translation>Pretočiť na: %1</translation>
    </message>
</context>
<context>
    <name>MainVisual</name>
    <message>
        <location filename="../mainvisual.cpp" line="243"/>
        <source>Visualization Mode</source>
        <translation>Režim vizualizácií</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="246"/>
        <source>Analyzer</source>
        <translation>Analyzér</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="247"/>
        <source>Scope</source>
        <translation>Osciloskop</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="248"/>
        <source>Off</source>
        <translation>Vypnuté</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="255"/>
        <source>Analyzer Mode</source>
        <translation>Režim analyzéra</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="258"/>
        <source>Normal</source>
        <translation>Normálny</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="259"/>
        <source>Fire</source>
        <translation>Oheň</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="260"/>
        <source>Vertical Lines</source>
        <translation>Stĺpce</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="261"/>
        <source>Lines</source>
        <translation>Čiary</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="262"/>
        <source>Bars</source>
        <translation>Prúžky</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="275"/>
        <source>Peaks</source>
        <translation>Špičky</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="279"/>
        <source>Refresh Rate</source>
        <translation>Obnovovacia frekvencia</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="282"/>
        <source>50 fps</source>
        <translation>50 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="283"/>
        <source>25 fps</source>
        <translation>25 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="284"/>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="285"/>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="292"/>
        <source>Analyzer Falloff</source>
        <translation>Pokles analyzéra</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="295"/>
        <location filename="../mainvisual.cpp" line="309"/>
        <source>Slowest</source>
        <translation>Najpomaljšie</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="296"/>
        <location filename="../mainvisual.cpp" line="310"/>
        <source>Slow</source>
        <translation>Pomaly</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="297"/>
        <location filename="../mainvisual.cpp" line="311"/>
        <source>Medium</source>
        <translation>Stredne</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="298"/>
        <location filename="../mainvisual.cpp" line="312"/>
        <source>Fast</source>
        <translation>Rýchlo</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="299"/>
        <location filename="../mainvisual.cpp" line="313"/>
        <source>Fastest</source>
        <translation>Najrýchlejšie</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="306"/>
        <source>Peaks Falloff</source>
        <translation>Pokles špičiek</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="319"/>
        <source>Background</source>
        <translation>Pozadie</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="320"/>
        <source>Transparent</source>
        <translation>Priehľadné</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Appearance</source>
        <translation type="unfinished">Vzhľad</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Shortcuts</source>
        <translation type="unfinished">Skratky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>View</source>
        <translation>Zobraziť</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Playlist</source>
        <translation>Playlist</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Tools</source>
        <translation>Nástroje</translation>
    </message>
</context>
<context>
    <name>PlayList</name>
    <message>
        <location filename="../playlist.cpp" line="207"/>
        <source>Sort List</source>
        <translation>Triediť zoznam</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="210"/>
        <location filename="../playlist.cpp" line="253"/>
        <source>By Title</source>
        <translation>Podľa názvu</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="214"/>
        <location filename="../playlist.cpp" line="257"/>
        <source>By Album</source>
        <translation>Podľa albumu</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="218"/>
        <location filename="../playlist.cpp" line="261"/>
        <source>By Disc Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="222"/>
        <location filename="../playlist.cpp" line="265"/>
        <source>By Artist</source>
        <translation>Podľa interpréta</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="226"/>
        <location filename="../playlist.cpp" line="269"/>
        <source>By Filename</source>
        <translation>Podľa názvu súboru</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="230"/>
        <location filename="../playlist.cpp" line="273"/>
        <source>By Path + Filename</source>
        <translation>Podľa cesty a názvu súboru</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="234"/>
        <location filename="../playlist.cpp" line="277"/>
        <source>By Date</source>
        <translation>Podľa dátumu</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="242"/>
        <location filename="../playlist.cpp" line="285"/>
        <source>By File Creation Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="250"/>
        <source>Sort Selection</source>
        <translation>Potriediť výber</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="293"/>
        <source>Randomize List</source>
        <translation>Zamiešať zoznam</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="295"/>
        <source>Reverse List</source>
        <translation>Otočiť zoznam</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="565"/>
        <source>&amp;New PlayList</source>
        <translation>&amp;Nový playlist</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="178"/>
        <source>&amp;Copy Selection To</source>
        <translation>&amp;Skopírovať výber do</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="53"/>
        <source>Playlist</source>
        <translation>Playlist</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="238"/>
        <location filename="../playlist.cpp" line="281"/>
        <source>By Track Number</source>
        <translation>Podľa čísla skladby</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="302"/>
        <source>Actions</source>
        <translation>Činnosti</translation>
    </message>
</context>
<context>
    <name>PlayListBrowser</name>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="14"/>
        <source>Playlist Browser</source>
        <translation>Prehliadač playlistu</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="45"/>
        <source>New</source>
        <translation>Nový</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="52"/>
        <location filename="../playlistbrowser.cpp" line="40"/>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="69"/>
        <location filename="../forms/playlistbrowser.ui" line="79"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../playlistbrowser.cpp" line="39"/>
        <source>Rename</source>
        <translation>Premenovať</translation>
    </message>
</context>
<context>
    <name>PlayListSelector</name>
    <message>
        <location filename="../playlistselector.cpp" line="50"/>
        <source>&amp;Load</source>
        <translation>&amp;Načítať</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="51"/>
        <source>&amp;Save As...</source>
        <translation>&amp;Uložiť ako...</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="53"/>
        <source>Rename</source>
        <translation>Premenovať</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="54"/>
        <source>&amp;Delete</source>
        <translation>&amp;Vymazať</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="125"/>
        <source>Rename Playlist</source>
        <translation>Premenovať playlist</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="125"/>
        <source>Playlist name:</source>
        <translation>Název playlistu:</translation>
    </message>
</context>
<context>
    <name>PopupSettings</name>
    <message>
        <location filename="../forms/popupsettings.ui" line="14"/>
        <source>Popup Information Settings</source>
        <translation>Nastavenie informácií v upozornení</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="75"/>
        <source>Show cover</source>
        <translation>Zobraziť obal</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="115"/>
        <source>Transparency:</source>
        <translation>Priehľadnosť:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="145"/>
        <source>Delay:</source>
        <translation>Oneskorenie:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="178"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="89"/>
        <source>Cover size:</source>
        <translation>Veľkosť obalu:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="29"/>
        <source>Template</source>
        <translation>Šablóna</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="58"/>
        <source>Reset</source>
        <translation>Zresetovať</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="65"/>
        <source>Insert</source>
        <translation>Vložiť</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="62"/>
        <source>Artist</source>
        <translation>Interprét</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="63"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="64"/>
        <source>Title</source>
        <translation>Názov</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="65"/>
        <source>Track number</source>
        <translation>Číslo skladby</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="66"/>
        <source>Two-digit track number</source>
        <translation>Dvojmiestne číslo skladby</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="67"/>
        <source>Genre</source>
        <translation>Žáner</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="68"/>
        <source>Comment</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="69"/>
        <source>Composer</source>
        <translation>Skladateľ</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="70"/>
        <source>Duration</source>
        <translation>Dĺžka</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="71"/>
        <source>Disc number</source>
        <translation>Číslo disku</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="72"/>
        <source>File name</source>
        <translation>Názov súboru</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="73"/>
        <source>File path</source>
        <translation>Cesta k súboru</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="74"/>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="75"/>
        <source>Condition</source>
        <translation>Stav</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../forms/preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>Editor predvolieb</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="77"/>
        <source>Load</source>
        <translation>Načítať</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="84"/>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="36"/>
        <source>Preset</source>
        <translation>Predvoľba</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="52"/>
        <source>Auto-preset</source>
        <translation>Automatická predvoľba</translation>
    </message>
</context>
<context>
    <name>ShortcutDialog</name>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="14"/>
        <source>Change Shortcut</source>
        <translation>Zmeniť skratku</translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Stlačte klávesovú kombináciu ktorú chcete priradiť</translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="52"/>
        <source>Clear</source>
        <translation>Vyčistiť</translation>
    </message>
</context>
<context>
    <name>SkinnedFactory</name>
    <message>
        <location filename="../skinnedfactory.cpp" line="31"/>
        <source>Skinned User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="44"/>
        <source>About Qmmp Skinned User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="45"/>
        <source>Qmmp Skinned User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="46"/>
        <source>Simple user interface with Winamp-2.x/XMMS skins support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="47"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="50"/>
        <source>Artwork:
Andrey Adreev &lt;andreev00@gmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SkinnedSettings</name>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="24"/>
        <source>Skins</source>
        <translation type="unfinished">Skiny</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="55"/>
        <source>Add...</source>
        <translation type="unfinished">Pridať...</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="68"/>
        <source>Refresh</source>
        <translation type="unfinished">Obnoviť</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="89"/>
        <location filename="../forms/skinnedsettings.ui" line="95"/>
        <source>View</source>
        <translation type="unfinished">Zobraziť</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="101"/>
        <source>Hide on close</source>
        <translation type="unfinished">Skryť pri zatvorení</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="108"/>
        <source>Start hidden</source>
        <translation type="unfinished">Spustiť skryté</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="115"/>
        <source>Use skin cursors</source>
        <translation type="unfinished">Použiť kurzory zo skinu</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="131"/>
        <source>Fonts</source>
        <translation type="unfinished">Písma</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="149"/>
        <source>Player:</source>
        <translation type="unfinished">Prehrávač:</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="171"/>
        <location filename="../forms/skinnedsettings.ui" line="219"/>
        <source>???</source>
        <translation type="unfinished">???</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="178"/>
        <location filename="../forms/skinnedsettings.ui" line="226"/>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="197"/>
        <source>Playlist:</source>
        <translation type="unfinished">Playlist:</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="233"/>
        <source>Use bitmap font if available</source>
        <translation type="unfinished">Použiť bitmapové písmo, ak je dostupné</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="243"/>
        <source>Transparency</source>
        <translation type="unfinished">Priehľadnosť</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="249"/>
        <source>Main window</source>
        <translation type="unfinished">Hlavné okno</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="272"/>
        <location filename="../forms/skinnedsettings.ui" line="296"/>
        <location filename="../forms/skinnedsettings.ui" line="320"/>
        <source>0</source>
        <translation type="unfinished">0</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="279"/>
        <source>Equalizer</source>
        <translation type="unfinished">Ekvalizér</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="303"/>
        <source>Playlist</source>
        <translation type="unfinished">Playlist</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="344"/>
        <source>Miscellaneous</source>
        <translation type="unfinished">Rôzne</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="350"/>
        <source>Song Display</source>
        <translation type="unfinished">Zobrazenie skladby</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="356"/>
        <source>Show protocol</source>
        <translation type="unfinished">Zobraziť protokol</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="363"/>
        <source>Show song numbers</source>
        <translation type="unfinished">Zobrazovať čísla piesní</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="387"/>
        <source>Show playlists</source>
        <translation type="unfinished">Zobrazovať playlisty</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="394"/>
        <source>Show popup information</source>
        <translation type="unfinished">Zobrazovať upozornenia s informáciami</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="406"/>
        <source>Edit template</source>
        <translation type="unfinished">Upraviť šablónu</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="430"/>
        <source>Playlist separator:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="468"/>
        <source>Show &apos;New Playlist&apos; button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="380"/>
        <source>Show anchor</source>
        <translation type="unfinished">Zobrazovať ukotvenie</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="373"/>
        <source>Align song numbers</source>
        <translation type="unfinished">Zarovnať čísla piesní</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="101"/>
        <source>Select Skin Files</source>
        <translation type="unfinished">Vybrať súbory skinov</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="102"/>
        <source>Skin files</source>
        <translation type="unfinished">Súbory skinov</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="150"/>
        <source>Unarchived skin</source>
        <translation type="unfinished">Nearchivovaný skin</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="181"/>
        <source>Archived skin</source>
        <translation type="unfinished">Archivovaný skin</translation>
    </message>
</context>
<context>
    <name>TextScroller</name>
    <message>
        <location filename="../textscroller.cpp" line="53"/>
        <source>Autoscroll Songname</source>
        <translation>Automaticky skrolovať názov piesne</translation>
    </message>
    <message>
        <location filename="../textscroller.cpp" line="54"/>
        <source>Transparent Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../textscroller.cpp" line="123"/>
        <source>Buffering: %1%</source>
        <translation>Bufferuje sa:%1%</translation>
    </message>
</context>
<context>
    <name>VisualMenu</name>
    <message>
        <location filename="../visualmenu.cpp" line="26"/>
        <source>Visualization</source>
        <translation>Vizualizácie</translation>
    </message>
</context>
</TS>
